# LEシリーズPC操作ライブラリ Pythonラッパー作成サンプル

本ディレクトリでは、プロトコルアナライザー LE シリーズを Python から操作する場合に
参考としていただくためのラッパーライブラリ実装の例を収録しています。

## 注意事項

- 本サンプルはご自由にご使用いただけますが、動作保証は一切行っておりませんのでご了承ください。

## 動作確認環境

本サンプルは Python 3.10 以降に対応しており、下記環境にて動作を確認しております。

同等の環境をお使いの場合、dist ディレクトリ下のビルド済みパッケージをご利用いただけます。

| ディストリビューション | CPUアーキテクチャ | libLEPCバージョン | Pythonバージョン | ビルド済みパッケージ名                      |
|:---------------------|:----------------|:-----------------|:----------------|:------------------------------------------|
| Ubuntu 22.04 LTS     | x86_64          | V1.03            | 3.10            | lepcpy-1.0.0-cp310-cp310-linux_x86_64.whl |
| Ubuntu 22.04 LTS     | x86_64          | V1.03            | 3.11            | lepcpy-1.0.0-cp311-cp311-linux_x86_64.whl |
| Ubuntu 22.04 LTS     | x86_64          | V1.03            | 3.12            | lepcpy-1.0.0-cp312-cp312-linux_x86_64.whl |
| Debian 12 (bookworm) | i686            | V1.03            | 3.10            | lepcpy-1.0.0-cp310-cp310-linux_i686.whl   |
| Debian 12 (bookworm) | i686            | V1.03            | 3.11            | lepcpy-1.0.0-cp311-cp311-linux_i686.whl   |
| Debian 12 (bookworm) | i686            | V1.03            | 3.12            | lepcpy-1.0.0-cp312-cp312-linux_i686.whl   |

ビルド済みパッケージは、下記コマンドにてインストールが可能です。

```bash
pip install 上記ビルド済みパッケージへのパス
```

## ビルドの手順

例として、Ubuntu 22.04 LTS (x86_64)、Python 3.10 での手順を示します。

1. libLEPC をダウンロードし、 libLEPC の README.txt に記載の手順でインストールします。

2. libLEPC に含まれている LEPC.h を、 lepcpy ディレクトリ下にコピーします。

3. ビルドに必要な追加パッケージをインストールします。

```bash
sudo apt install python3 python3-pip python3-venv build-essential
```

4. ビルド用の Python 仮想環境を作成し、有効にします。

```bash
python3 -m venv .venv
. .venv/bin/activate
```

5. パッケージをビルド、インストールします。

```bash
pip install .
```

## サンプルスクリプトについて

example ディレクトリ下に、本ラッパーライブラリの活用例としてサンプルスクリプトを収録しています。

`analyzer_emu.py` 、 `line_state.py` をお試しいただく際は、下記のパッケージを追加でインストールする必要があります。

```bash
sudo apt install libgtk-3-dev libwxgtk3.0-gtk3-dev
pip install wxPython
```

`key.py` をお試しいただく際は、下記のパッケージを追加でインストールする必要があります。

```bash
sudo apt install python3-tk
```

### analyzer_emu.py

Windows 版PCリンクソフト LE-PC800シリーズ、LE-PC300シリーズ等に搭載のキーエミュレーション操作機能をPC操作ライブラリで再現するサンプルです。

実機を操作する感覚でリモート操作が可能です。

#### 使用方法

example ディレクトリに移動し、下記コマンドで実行します。

```bash
python ./analyzer_emu.py
```

テキストボックスにて、接続先機器を指定することができます。空欄にした場合、接続先機器を探して自動で接続します。

#### ご注意

- リンクソフトのフル機能版に比べて一部機能制限があります。
- シリアル接続での使用は遅延が大きく、動作に問題が起こる可能性があります。
- 表示更新に200ms 程度の遅延が生じます。
- シフトキーはトグル動作しますが、長押しによってF1-F5キーの機能変化を確認することはできません。
- タッチパネル操作のエミュレーションはできません。

### key.py

上記 `analyzer_emu.py` を、キー操作のみに絞ることでより簡易的にしたサンプルです。

#### 使用方法

example ディレクトリに移動し、接続先機器を指定する引数を付けて実行します。

```bash
python ./key.py 接続先機器の指定
```

### line_state.py

制御線の状態を取得し、波形表示するデモサンプルです。

#### 使用方法

example ディレクトリに移動し、下記コマンドで実行します。

```bash
python ./line_state.py
```

テキストボックスにて、接続先機器を指定することができます。空欄にした場合、接続先機器を探して自動で接続します。

Connect 、 Start の順でボタンを押し、波形表示を開始します。

### dump_pcap.py

LAN測定ボードをセットしたLEシリーズと接続し、一定時間の測定を行い、測定データをpcapng 形式で出力するデモサンプルです。

pcapng ファイルはフリーソフトのWireshark で読み込むことができます。

#### 使用方法

example ディレクトリに移動し、接続先機器を指定する引数を付けて実行します。

```bash
python ./dump_pcap.py 接続先機器の指定
```

### counter.py

本体のトリガー0とトリガー1の設定を書き換え、一定時間の測定を行った後にタイマー0、カウンター0の値を表示するデモサンプルです。

トリガー0で、測定開始後初めてデータを受信したときにタイマー0をスタートします。

トリガー1で、測定データ受信毎にカウンター0をインクリメントします。

#### 使用方法

example ディレクトリに移動し、接続先機器を指定する引数を付けて実行します。

```bash
python ./counter.py 接続先機器の指定
```

### read_dt.py

DT ファイル形式で保存した測定データを可読な形式に変換して表示するサンプルです。機器本体とは通信しません。

#### 使用方法

example ディレクトリに移動し、DTファイルへのパスを引数に付けて実行します。

```bash
python ./read_dt.py DTファイルへのパス
```

## ライセンス情報

dist ディレクトリ下のビルド済みパッケージには、BSDライセンスのもとで提供される pybind11 が含まれています。

```
Copyright (c) 2016 Wenzel Jakob <wenzel.jakob@epfl.ch>, All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright notice, this
   list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright notice,
   this list of conditions and the following disclaimer in the documentation
   and/or other materials provided with the distribution.

3. Neither the name of the copyright holder nor the names of its contributors
   may be used to endorse or promote products derived from this software
   without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

Please also refer to the file .github/CONTRIBUTING.md, which clarifies licensing of
external contributions to this project including patches, pull requests, etc.
```
